@@ -182,12 +182,17 @@ public class AudioBrowserFragment extends BrowserFragment implements SwipeRefres
 
     AbsListView.OnScrollListener mScrollListener = new AbsListView.OnScrollListener(){
             @Override
-            public void onScrollStateChanged(AbsListView view, int scrollState) {}
+            public void onScrollStateChanged(AbsListView view, int scrollState) {
+                boolean enabled = scrollState == SCROLL_STATE_IDLE;
+                if (enabled) {
+                    enabled = view.getFirstVisiblePosition() == 0;
+                    enabled &= view.getChildAt(0).getTop() == 0;
+                }
+                mSwipeRefreshLayout.setEnabled(enabled);
+            }
             @Override
             public void onScroll(AbsListView view, int firstVisibleItem, int visibleItemCount,
-                                 int totalItemCount) {
-                mSwipeRefreshLayout.setEnabled(firstVisibleItem == 0);
-            }
+                                 int totalItemCount) {}
     };
 
     @Override
@@ -517,7 +522,7 @@ public class AudioBrowserFragment extends BrowserFragment implements SwipeRefres
             mHandler.sendEmptyMessageDelayed(MSG_LOADING, 300);
 
             ExecutorService tpe = Executors.newSingleThreadExecutor();
-            ArrayList<Runnable> tasks = new ArrayList<>(Arrays.asList(updateArtists,
+            ArrayList<Runnable> tasks = new ArrayList<Runnable>(Arrays.asList(updateArtists,
                     updateAlbums, updateSongs, updateGenres));
 
             //process the visible list first
